# Sci-Eng-Interface

This package provides engineering specifications for telescope, instrument, 
and detector properties for the Habitable Worlds Observatory 

> pip install hwo_sci_eng 
> export SCI_ENG_DIR=/Users/tumlinson/anaconda3/envs/hwotools/lib/python3.12/site-packages/hwo_sci_eng
or a path suitable for your system, that points to the install location of the package. 

